@@ -35,20 +35,5 @@ def mediautils_rotate_photo(request, pk, direct='left', MediaModel=Media):
         orig_name = file_field.name
         img_file = file_field.path
         rotate_image(img_file, direct)
-        base_name = os.path.basename(img_file)
-        fname, ext = os.path.splitext(base_name)
-        random_name = uuid4().hex
-        new_path = img_file.replace(fname, random_name)
-        new_name = orig_name.replace(fname, random_name)
-        os.rename(img_file, new_path)
-        if field == 'media_file':
-            media.media_file.name = new_name
-        elif field == 'media_thumbnail':
-            media.media_thumbnail.name = new_name
-        media.save()
-        #media.refresh_from_db()
-        #assert os.path.isfile(getattr(media, field, None).path)
-        #assert new_name in getattr(media, field, None).path
-        #assert new_name in getattr(media, field, None).url
     return media
 
